# IAR Transcriber

The IAR (Iván Arias Rodríguez) Transcriber is a transcriber developed for Spanish. It is able to get the
 phonetic transcription of a Spanish text.

More information to be added in the future...